#![allow(unused_variables)]
#![allow(clippy::many_single_char_names)]

use crate::activated_color;
use fltk::{app, draw::*, enums::Color};

pub mod aqua;
pub(crate) mod clean;
pub(crate) mod crystal;
pub mod fluent;
pub(crate) mod gleam;
pub(crate) mod svg_based;
